Keyboard shortcuts

Press or to navigate between chapters

Press S or / to search in the book

Press ? to show this help

Press Esc to hide this help

imports

imports contains a list of import entries, each representing a local or remote source for additional laze projects.

Example:

imports:
 - git:
    - url: https://github.com/kaspar030/laze
      tag: 0.1.17

import types