Keyboard shortcuts

Press or to navigate between chapters

Press S or / to search in the book

Press ? to show this help

Press Esc to hide this help

meta

This field is ignored by laze and can contain arbitrary data.

It is available on the top level, on contexts, modules, rules, and tasks, and can be used by external tools to attach metadata to laze build files.

Example:

modules:
  - name: my_module
    meta:
      maintainer: alice
      license: MIT